## S3 method for class 'RTdata,missing':
calculate.DVH(x, dose, resolution.xyz=c(0.2,0.2,NA),
resolution.dose=0.01, method=NULL, dose.units=NULL)## S3 method for class 'RTdata,array':
calculate.DVH(x, dose, resolution.xyz=c(0.2,0.2,NA),
resolution.dose=0.01, method=NULL, dose.units=NULL)
## S3 method for class 'structure3D,array':
calculate.DVH(x, dose, resolution.xyz=c(0.2,0.2,NA),
resolution.dose=0.01, method=NULL, dose.units=NULL)
## S3 method for class 'structure.list,array':
calculate.DVH(x, dose, resolution.xyz=c(0.2,0.2,NA),
resolution.dose=0.01, method=NULL, dose.units=NULL)
"structure3D" object, a "structure.list", or a "RTdata" object containing one or more structure(s)."array" containing dose grid data. This parameter is not required if x contains a "RTdata" object including dose grid information.c("ATC", "surface", or "axial". See below for further details about the dose calculation algorithms."cGy" (default) or "Gy"."DVH" object or a "DVH.list" object consisting of multiple DVHs where relevant, or otherwise a "zDVH" or "DVH.list" containing multiple zDVHs when method="axial".DVH, DVH.list, newdata("RadOnc")
# zDVHs <- calculate.DVH(janedoe.RTdata, method="axial")Run the code above in your browser using DataLab